"""vectormath: Vector math utilities for Python built on NumPy"""
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

from .vector import Vector3, Vector2, Vector3Array, Vector2Array

__version__ = '0.2.0'
__author__ = 'Seequent'
__license__ = 'MIT'
__copyright__ = 'Copyright 2018 Seequent'
